
TODO_77_12_50_80 some lists with suggestions contain same values (repeated, duplicated, etc.).

While it is not a problem for Bash (it removes duplicates and displays unique values),
this may be a sign of a bug and generally looks bad (e.g. in tests). 
